#! /usr/bin/env python

import os, sys
import numpy

def Usage():
    print >>sys.stderr, """Usage: %s [-o outstem] [-binary] [-i in.speck] [-n nsteps] [-d timespan]""" % sys.argv[0]
    sys.exit(1)


outstem = None
inspeck = "hip.speck"
as_binary = False
nsteps = 1
timespan = 0.0
maxmag = 12

ii = 1
while ii<len(sys.argv) and sys.argv[ii][0] == '-':
    opt = sys.argv[ii]; ii += 1
    if opt == '-o':
	outstem = sys.argv[ii]; ii += 1
    elif opt[:2] == '-b':
	as_binary = True
    elif opt == '-i':
	inspeck = sys.argv[ii]; ii += 1
    elif opt == '-n':
	nsteps = int( sys.argv[ii] ); ii += 1
    elif opt == '-d':
	timespan = float( sys.argv[ii] ); ii += 1
    elif opt == '-m':
	maxmag = float( sys.argv[ii] ); ii += 1
    else:
	Usage()


if nsteps > 1 and timespan == 0.0:
    print >>sys.stderr, "Really want to write %d identical output files?   Try -d timespan (e.g. -d 0.1) too." % nsteps

if inspeck is None or outstem is None:
    Usage()

icolor = 3 + 0
imag = 3 + 3
ivx = 3 + 5

points = []

with open(inspeck) as inf:
    for line in inf.readlines():
	ss = line.split('#')[0].split()
	if len(ss) < ivx+3:
	    continue
	try:
	    vv = map(float, ss)
	    if vv[imag] >= maxmag:
		continue
	    points.append( vv )
	except:
	    pass

points = numpy.array( points )

print "Keeping %d stars" % len(points)

if '%' not in outstem:
    if os.path.isdir(outstem):
	outstem = os.path.join( outstem, os.path.split(outstem)[1] )
    if as_binary:
	outstem += '.%04d.bin'
    else:
	outstem += '.%04d.speck'

times = numpy.linspace( 0, timespan, num=nsteps )

for i, time in enumerate( times ):
    outfname = outstem % i
    with open(outfname, 'wb') as outf:
	vv = numpy.empty( (len(points), 3+1), dtype=numpy.float32 )
	vv[:, 0:3] = points[:, 0:3] + time * points[:, ivx : ivx+3]
	vv[:, 3] = points[:, icolor]

	if as_binary:
	    header = numpy.array([ 0x12345678, len(vv), len(vv[0]) ], dtype=numpy.int32)
	    header.tofile( outf )
	    vv.tofile( outf )

	else:
	    for v in vv:
		print >>outf, "%g %g %g %g" % tuple(v)
